@@ -34,7 +34,7 @@ use Cache::Memory::Entry;
 use base qw(Cache);
 use fields qw(namespace);
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 
 # storage for all data
@@ -293,7 +293,7 @@ sub del_expiry_from_heap {
     my Cache::Memory $self = shift;
     my ($key, $exp_elem) = @_;
 
-    $Expiry_Heap->del($exp_elem);
+    $Expiry_Heap->delete($exp_elem);
 }
 
 sub add_age_to_heap {
@@ -361,12 +361,12 @@ Cache
 
 =head1 COPYRIGHT
 
- Copyright (C) 2003 Chris Leishman.  All Rights Reserved.
+ Copyright (C) 2003-2006 Chris Leishman.  All Rights Reserved.
 
 This module is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
 either expressed or implied. This program is free software; you can
 redistribute or modify it under the same terms as Perl itself.
 
-$Id: Memory.pm,v 1.7 2005/10/20 12:52:03 caleishm Exp $
+$Id: Memory.pm,v 1.9 2006/01/31 15:23:58 caleishm Exp $
 
 =cut
